# laz-rs-python

Python bindings for the [laz-rs](https://crates.io/crates/laz) crate.


# Building

Building is done by using [maturin](https://github.com/PyO3/maturin)

```console
# from pypi
pip install lazrs

# localy
pip install .
```

or

```console
pip install maturin
maturin develop --release
```